//  GLC.C
//  Program for conversion between Gregorian dates
//  and dates in the Goddess lunar calendar.
//  Author: Peter Meyer
//  Last mod.: 1996-09-22 G (2996-24-11 GLC)

#include <STDIO.H>
#include <CONIO.H>
#include <STDLIB.H>
#include <STRING.H>
#include <DOS.H>

#include "DATECONV.H"
#include "LUNCONV.H"

#define ESCAPE 0x1B
#define CONTROL_Q 0x11

unsigned char *version =
    #ifdef GE
    "\nLKG.EXE"
    #else
    "\nGLC.EXE"
    #endif
    ", Version 2.7, "
    #ifdef GE
    "von"
    #else
    "by"
    #endif
    " Peter Meyer\n";

unsigned char *usage =
#ifdef GE
"\nDieses Programm akzeptiert als Eingabe entweder ein Datum im\n"
"gregorianischen Kalender, ein Datum im Lunarkalender der Gttinnen oder\n"
"eine Tageszahl in julianischer Zahlung. Danach zeigt das Programm eine\n"
"Serie von Datumsangaben und die zugehrigen julianischen Tageszahlen.\n"
"\nFormat fr die Eingabe eines gregorianischen Datums:     LKG Jahr-Monat-Tag G"
"\nFormat fr die Eingabe eines lunaren Datums i.K.d.G.:    LKG Jahr-Monat-Tag L"
"\nFormat fr die Eingabe einer julianischen Tageszahl:     LKG Jul.Tageszahl"
"\nFormat fr eine Krzbeschreibung der 25 Gttinnen:       LKG G"
"\nEingabe, um diesen Hilfetext und das gegenw&auml;rtige Datum, zu erhalten: LKG\n\n"
"Um das Programm zu verlassen, bitte ESCAPE oder CONTROL-Q drucken, irgend\n"
"eine andere Taste liefert sukzessive Datumsangaben. Wird die Ausf&uuml;hrung des\n"
"Programms vom DOS-Promptzeichen aus gestartet, dann kann die Ausgabe des\n"
"Programms auch in eine Datei (\">X\") oder einen Drucker (\">PRN\") umgeleitet\n"
"werden.\n"
#else
"\nThis program accepts as input either a date in the Gregorian calendar,\n"
"a date in the Goddess lunar calendar or a Julian day number. It then\n"
"displays a series of date and Jdn correspondences.\n"
"\nFor entry of a Gregorian date use:            GLC year-month-day G"
"\nFor entry of a Goddess lunar date use:        GLC year-month-day L"
"\nFor entry of a Julian day number use:         GLC Jdn"
"\nFor a brief description of the goddesses use: GLC G"
"\nFor this help text and the current date use:  GLC\n\n"
"Press Escape or control-Q to quit, any other key for successive dates.\n"
"When run from the DOS prompt output may be redirected to a file (\">X\")\n"
"or to a printer (\">PRN\").\n"
#endif
;

char *cal_spec =
#ifdef GE
"\nKalender mus spezifiziert werden: G(regorianisch) or L(unar)\n"
#else
"\nCalendar must be specified: G(regorian) or L(unar)\n"
#endif
;

char euro_weekdays[][12] = {
#ifdef GE
"Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag",
"Samstag", "Sonnabend"
#else
"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday",
"Saturday"
#endif
};

char lunar_months[26][14]
  = { { "" },
      { "Artemis" },  { "Bast" },     { "Cybele" },       { "Durga" },
      { "Eris" },     { "Freya" },    { "Gaea" },         { "Hathor" },
      { "Ix Chel" },  { "Juno" },     { "Kali" },         { "Luna" },
      { "Maat" },     { "Nisaba" },   { "Oya" },          { "Persephone" },
      { "Quan Yin" }, { "Rhiannon" }, { "Saraswati" },    { "Tara" },
      { "Usha" },     { "Venus" },    { "Waka-Hiru-Me" }, { "Xochiquetzal" },
      { "Yemaya" } };

char *goddesses[25]  = {
#if GE
"Artemis      Griechische Mondgttin und Gttin der Jagd und der Natur",
"Bast         Agyptische Mondgttin, eine Frau mit einem Katzenkopf",
"Cybele       Phrygische Gttin der Natur und Fruchtbarkeit",
"Durga        Indische Gttin, Damonenvernichterin, Gattin von Shiva",
"Eris         Griechische  Gttin der Chaos und Unordnung",
"Freya        Germanische Gttin der Liebe, der Schnheit und der Geburt",
"Gaea         Griechische Gttin der Erde",
"Hathor       Agyptische Gttin und Gttin des Himmels",
"Ix Chel      Mondgttin der Mayas, Gttin der Heilkunst und der Geburt",
"Juno         Romische Knigin der Gtter, Beschtzerin der Frauen",
"Kali         Hindugttin, Gattin von Shiva",
"Luna         Rmische Mondgttin",
"Maat         Agyptische Gttin der Wahrheit, Sophia",
"Nisaba       Sumerische Gttin der Astronomie und des Kalenderwesens",
"Oya          Fruchtbarkeitsgttin der Yoruba, eine Gttin der Sturme",
"Persephone   Griechische Gttin der Natur, Tochter des Zeus",
"Quan Yin     Chinesische Gttin des Mitgefuhls",
"Rhiannon     Keltische Gttin, Verbindung mit Pferden",
"Saraswati    Hindugttin der Wissenschaft, der Literatur und der Kunste",
"Tara         Buddhistische Gttin des Mitgefuhls",
"Usha         Vedische Gttin der Dmmerung",
"Venus        Rmische Gttin der Liebe",
"Waka-Hiru-Me Japanische Gttin der aufgehenden Sonne",
"Xochiquetzal Aztekische Gttin der Blumen",
"Yemaya       Yorubagttin der Flusse, des Meeres, Mutter der Gtter"
#else
"Artemis      Greek moon goddess and goddess of hunting and Nature",
"Bast         Egyptian moon goddess, a cat-headed woman",
"Cybele       Phrygian goddess of nature and fertility",
"Durga        Indian goddess, destroyer of demons, wife of Shiva",
"Eris         Greek goddess of chaos and disorder",
"Freya        German goddess of love, beauty and childbirth",
"Gaea         Greek goddess of Earth",
"Hathor       Egyptian sky goddess and queen of heaven",
"Ix Chel      Maya moon goddess, goddess of healing and of childbirth",
"Juno         Roman queen of the gods, protector of women",
"Kali         Hindu goddess, wife of Shiva",
"Luna         Roman moon goddess",
"Maat         Egyptian goddess of truth, Sophia",
"Nisaba       Sumerian goddess of astronomy, mathematics and the calendar",
"Oya          Yoruba fertility goddess, a goddess of wind and storms",
"Persephone   Greek goddess of Nature, daughter of Zeus",
"Quan Yin     Chinese goddess of Compassion",
"Rhiannon     Celtic goddesses associated with horses",
"Saraswati    Hindu goddess of science, literature and the arts",
"Tara         Buddhist goddess of Compassion",
"Usha         Vedic goddess of the dawn",
"Venus        Roman goddess of love",
"Waka-Hiru-Me Japanese goddess of the rising sun",
"Xochiquetzal Aztec goddess of flowers",
"Yemaya       Yoruba goddess of rivers and the sea, mother of the gods"
#endif
};

unsigned char temp[64], temp1[64];

union REGS regs;

void get_current_date(Date *dp);

/*----------------------------*/
void main(int argc,char *argv[])
{
int i, conv=FALSE;
long jdn;
Date date;
char ch, cal=0;

printf(version);

if ( argc == 1 )
    {
    printf(usage);
    //  Read current system date
    get_current_date(&date);
    date.calendar = 'G';
    euro_date_to_jdn(&date);
    conv = TRUE;
    }
else if ( argc == 3 )
    {
    //  It's a date with calendar specification.
    iso_date_to_date(argv[1],&date);
    cal = argv[2][0];
    cal = cal - 32*(cal>'Z');
    if ( ! ( cal == 'L' || cal == 'G' ) )
        {
        printf(cal_spec);
        exit(1);
        }
    date.calendar = cal;
    if ( cal == 'L' )
        goddess_date_to_jdn(&date);
    else
        euro_date_to_jdn(&date);
    if ( date.valid )
        conv = ( labs(date.year) <= 2800000L );
    }
else
    {
    strupr(argv[1]);
    if ( argv[1][0] == 'G' )
        {
        for ( i=0; i<25; i++ )
            printf("\n%s",goddesses[i]);
        printf("\n");
        exit(0);
        }
    else    //  Presumably it's a jdn.
        {
        date.jdn = atol(argv[1]);
        sprintf(temp,"%ld",date.jdn);
        if ( strlen(temp) == strlen(argv[1]) )
            conv = TRUE;
        else    //  Nope.
            {
            iso_date_to_date(argv[1],&date);
            if ( date.valid )
                {
                printf(usage);
                printf(cal_spec);
                exit(2);
                }
            }
        }
    }

if ( !conv )
    {
    #ifdef GE
    printf("\nUngltige Eingabe.\n");
    #else
    printf("\nInvalid input.\n");
    #endif
    exit(3);
    }

jdn = date.jdn;

//  Display a sequence of corresponding dates

#ifdef GE
printf("\n%14s%48s%17s\n\n",
    "Gregorianisch",
    "----------- Lunardatum i.K.d.G. -----------",
    "Jul.Tageszahlung"
#else
printf("\n%14s%48s%16s\n\n",
    "Gregorian",
    "---------- Goddess calendar date ----------",
    "Julian day no."
#endif
);


while ( TRUE )
    {
    date.jdn = jdn;
    date.calendar = 'G';
    jdn_to_euro_date(&date);
    date_to_iso_date(&date,temp,FALSE,0);
    printf("%14s",temp);

    date.jdn = jdn;
    jdn_to_goddess_date(&date);
    date_to_iso_date(&date,temp,FALSE,0);
    printf("%15s",temp);

    #ifdef GE
    printf("%11s",euro_weekdays[euro_day_of_week(jdn)]);
    #else
    printf("%10s",euro_weekdays[euro_day_of_week(jdn)]);
    #endif

    printf(", %12s %2d, %-8ld",lunar_months[date.month],date.day,date.year);

    ltoa(jdn,temp,10);
    separate_thousands(temp,temp1,',');
    printf("%-12s\n",temp1);

    while  ( !kbhit() )
        ;

    ch = getch();
    if ( ch == ESCAPE || ch == CONTROL_Q )
        exit(0);

    jdn++;
    }
}


/*---------------------------*/
void get_current_date(Date *dp)
{
regs.h.ah = 0x2A;
int86(0x21,&regs,&regs);
dp->year = regs.x.cx;
dp->month = regs.h.dh;
dp->day = regs.h.dl;
}

