/*
 *
 *  Psych0Day 
 *
 *     PDAY.H -- fun exciting super-header
 *
 *
 */

#ifndef PDAY__H
#define PDAY__H

#include <stdio.h>
#include <stdlib.h>

#define INC_CRITERR
#include "common.c"


#include "commafmt.c"             /* found in SNIPPETS */
#include "l2roman.c"              /* SNIPPETS */
#include "ord_text.c"             /* SNIPPETS */

#include "daynum.c"               /* SNIPPETS */
#include "jdn_l.c"                /* SNIPPETS */
#include "scaldate.c"             /* SNIPPETS */

#include "french.c"               /* sdncal */
#include "julian.c"               /* sdncal */
#ifndef NO_JEWISH
#include "jewish.c"               /* sdncal -- doesn't work yet */
#endif
/* the two above, french.c and julian.c, require modification to coexist due
   to a conflict of #DEFINEd names used internally */

#include "lunconv.c"              /* glc */

#include "d:\c\pday\pdaysup.c"    


/* -- compilers ------------------------------------------------------ */

/* Turbo C v3.00 */
#if defined(__TURBOC__)       
#include <dos.h>
#define USE_FOPEN
#define UNIXTIME
#define COMPILER_NAME "Turbo"
#endif

/* GNU EMX/GCC (OS/2) v0.9c */
#if defined(__GNUC__)
#if defined(__EMX__)
 #define COMPILER_NAME "GNU/EMX"
 #else
 #define COMPILER_NAME "GNU"
 #endif
#define strcmpi(a,b)    stricmp(a,b)
#define USE_FOPEN
#define UNIXTIME
#define INC_DIRPORT
#define MAXDIR          255    /* this is bad for OS/2 but works for now */
#define MAXPATH         255    /* this too */
#endif

/* Psych0Day enjoys using fopen() and fgets() */
#if !defined(USE_FOPEN)
#include <fcntl.h>
#endif

/* Psych0Day likes this as well */
#if defined(UNIXTIME)
#include <time.h>
#endif

#if defined(INC_DIRPORT)
#include "dirport.c" 				              /* SNIPPETS */
#define  findfirst(a,b,c)      FIND_FIRST(a,c,b)
#define  findnext(a)           FIND_NEXT(a)
typedef DOSFileData DIRSTRUCT;
#if defined(OS2)
 #define  FINDATTR             FILE_NORMAL | FILE_ARCHIVED
 #define  ffname(a)            (a).f.d_name
 #endif
#else
#include <dir.h>
typedef struct ffblk DIRSTRUCT;
#define  FINDATTR             0
#define  ffname(a)            (a).ff_name
#endif


/* -- some #definitions ---------------------------------------------- */

#define MAX_FGETS_READ    256

#define PROG_BASENAME        "Psych0Day"
#define PROG_BASEVER         "1.00"
#include "name.h"


/* -- variables ------------------------------------------------------ */

typedef unsigned int bit;              /* shorthand for C bit fields */

typedef struct     /* command line options */
 {

    bit showmoon        : 1;  /* m */
    bit showastro       : 1;  /* not yet implemented */

    bit showdiscord     : 1;  /* d */
    bit showfrench      : 1;  /* f */
    bit showgoddesslunar: 1;  /* l */
    bit showgregorian   : 1;  /* g */
    bit showjewish      : 1;  /* w */
    bit showjulian      : 1;  /* j */
    bit showilluminati  : 1;  /* i */
    bit showthelemic    : 1;  /* t */

    bit showevents      : 1;  /* e */
    bit showbirthdays   : 1;  /* b */
    bit showreminders   : 1;  /* r */

 } optsrec;

typedef struct
 {
    int debuglevel;
    int quietlevel;

 } moptsrec;

#define GREGORIAN       1
#define JULIAN          2
#define FRENCH          3
#define GODDESSLUNAR    4
#define THELEMIC        5
#define DISCORD         6
#define ILLUMANTI       7
#define MOON            8

typedef struct {
 unsigned int  mday,              /* day of month (1-31) */
               month;             /* month of year (1-12) */
 YEAR          year;              /* year (?..-1, 1-?, never 0) */
 unsigned int  yday;              /* day of year (1-366) */
 unsigned int  wday;              /* day of week (1-7, 1=Sunday) */
 unsigned long JDN;               /* Julian Day Number (1-...big) */
 } gregrec;

#define T_UNDEFINED 0
#define T_COMMENT 1
#define T_EVENT 2
#define T_REMINDER 3
#define T_BIRTHDAY 4

typedef enum { undefined = T_UNDEFINED,
	       comment,
	       event,
	       reminder,
	       birthday } TYPE;

typedef struct {
 YEAR             year;
 TYPE             type;
 char             continued;         /* 0 = false, 1 true */
 char             text[80];

 } dataentryrec; /* size = 81 + 1 + 1 + 1 = 84 bytes */

#ifdef notused
typedef struct {
 YEAR             year;
 TYPE             type;
 char             continued;         /* 0 = false, 1 true */
 /* pointer       continuedfrom;  (for sorting) */
 char             *text;

 } dataentryrec;
#endif

optsrec      opts = { 1, 1,
                1, 1, 1, 1, 1, 1, 1, 0,
		      1, 1, 1 };

moptsrec     mopts = { 1, 1 };

#if defined(DOS)
#define MAX_DATAELEMENTS 100
#elif defined(OS2)
#define MAX_DATAELEMENTS 200
#endif

gregrec      greg;
dataentryrec dataarr[MAX_DATAELEMENTS];
int          dataelements = 1;


/* --- string thigns ------------------------------------------------- */

char *days[7] =
#if (!ISO_CAL)
 { "Sunday",
   "Monday",
   "Tuesday",
   "Wednesday",
   "Thursday",
   "Friday",
   "Saturday"};
#else
 { "Monday",
   "Tuesday",
   "Wednesday",
   "Thursday",
   "Friday",
   "Saturday",
   "Sunday"};
#endif

char *months[] =
 { "January",         /* 1 */
   "Febuary",         /* 2 */
   "March",           /* 3 */
   "April",           /* 4 */
   "May",             /* 5 */
   "June",            /* 6 */
   "July",            /* 7 */
   "August",          /* 8 */
   "September",
   "October",         /* 10 */
   "November",
   "December"};

char *poeeseasons[] =
 { "Chaos",
   "Discord",
   "Confusion",
   "Bureaucracy",
   "The Aftermath" };

char *poeedays[] =
 { "Sweetmorn",
   "Boomtime",
   "Pungenday",
   "Prickle-Prickle",
   "Setting Orange" };

char *illseasons[] =
 { "Verwirrung",
   "Zweitracht",
   "Unordnung",
   "Beamtennherrschaft",
   "Realpolitik" };

char *lunar_months[26] =
 { "Artemis",
   "Bast",
   "Cybele",
   "Durga",
   "Eris",
   "Freya",
   "Gaea",
   "Hathor",
   "Ix Chel",
   "Juno",
   "Kali",
   "Luna",
   "Maat",
   "Nisaba",
   "Oya",
   "Persephone",
   "Quan Yin",
   "Rhiannon",
   "Saraswati",
   "Tara",
   "Usha",
   "Venus",
   "Waka-Hiru-Me",
   "Xochiquetzal",
   "Yemaya" };

char *moontext[] =
 { "new",                  /* totally dark                         */
   "waxing crescent",      /* increasing to full & quarter light   */
   "first quarter",        /* increasing to full & half light      */
   "waxing gibbous",       /* increasing to full & > than half     */
   "full",                 /* fully lighted                        */
   "waning gibbous",       /* decreasing from full & > than half   */
   "last quarter",         /* decreasing from full & half light    */
   "waning crescent"       /* decreasing from full & quarter light */
    };

#ifdef INC_ASTROSIGNS
char *astrosigns[] =
 { "Aries",         /* March 21- April 19 */
   "Taurus",        /* April 20- May 20 */
   "Gemini",        /* May 21- June 20 */
   "Cancer",        /* June 21- July 22 */
   "Leo",           /* July 23- August 22 */
   "Virgo",         /* Aug 23- Sept 22 */
   "Libra",         /* Sept 23- Oct 22 */
   "Scorpio",       /* Oct 23- Nov 21 */
   "Sagittarius",   /* Nov 22- Dec 21 */
   "Capricorn",     /* Dec 22- Jan 19 */
   "Aquarius",      /* Jan 20- Feb 18 */
   "Pisces"   };    /* Feb 19- March 20 */
#endif

#ifdef INC_OLD_DAYS
char *old_days[7] =
 {"Sun's Day",
  "Moon's Day",
  "Mars' Day",
  "Mercury's Day",
  "Jupiter's Day",
  "Venus' Day",
  "Saturn's Day"};

char *older_days[7] =
 {"Sun's Day",
  "Moon's Day",
  "Tiw's Day",
  "Woden's Day",
  "Thor's Day",
  "Frigg's Day",
  "Saturn's Day"};
#endif

#endif /* PDAY__H */
